@@ -14,7 +14,8 @@ from pysam import VariantFile
 # Functions ====================================================================
 
 def parse_arguments():
-    parser = ArgumentParser(description='Filter VCF to variants that are private to a sample group')
+    parser = ArgumentParser(
+        description='Filter VCF to variants that are specific to a sample group')
     parser.add_argument('vcf', metavar='<input.vcf>', help='input VCF file')
     parser.add_argument('--groups', metavar='<"GROUP">', nargs='+',
                         help='specify a subset of sample groups')
